==> financial-settlement-client-0.1.254-sources.jar: com/xforceplus/financialsettlement/controller/FinancialWriteoffBasicBillFeignApi.java <==
package com.xforceplus.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-09-08
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.financialsettlement.entity.FinancialWriteoffBasicBill;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface FinancialWriteoffBasicBillFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/financialWriteoffBasicBill/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param financialWriteoffBasicBill ${table.comment}
   * @return R
   */
  @PostMapping("/financialWriteoffBasicBill/add")
  public R save(@RequestBody FinancialWriteoffBasicBill financialWriteoffBasicBill);

  /**
   * 修改${table.comment}
   * @param financialWriteoffBasicBill ${table.comment}
   * @return R
   */
  @PostMapping("/financialWriteoffBasicBill/update")
  public R updateById(@RequestBody FinancialWriteoffBasicBill financialWriteoffBasicBill);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/financialWriteoffBasicBill/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> financial-settlement-client-0.1.314-sources.jar: com/xforceplus/financialsettlement/controller/FinancialWriteoffBasicBillFeignApi.java <==
package com.xforceplus.financialsettlement.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-01-09
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.financialsettlement.entity.FinancialWriteoffBasicBill;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "financial-settlement")
public interface FinancialWriteoffBasicBillFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/financialWriteoffBasicBill/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param financialWriteoffBasicBill ${table.comment}
   * @return R
   */
  @PostMapping("/financialWriteoffBasicBill/add")
  public R save(@RequestBody FinancialWriteoffBasicBill financialWriteoffBasicBill);

  /**
   * 修改${table.comment}
   * @param financialWriteoffBasicBill ${table.comment}
   * @return R
   */
  @PostMapping("/financialWriteoffBasicBill/update")
  public R updateById(@RequestBody FinancialWriteoffBasicBill financialWriteoffBasicBill);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/financialWriteoffBasicBill/del/{id}" )
  public R removeById(@PathVariable Long id);

}
